# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from .prompt import Prompt

__all__ = ["PromptListResponse"]

PromptListResponse: TypeAlias = List[Prompt]
